LinearRegression

Struct LinearRegression 

pub struct LinearRegression { /* private fields */ }
An ordinary least squares univariate linear regression model.

Given predictors x and responses y ordinary least squares linear regression estimates a model of the form

y = xW + b

by finding a matrix W and a vector b which minimize the sum of the squared L_2 norms ||y_j - x_jW - b||_2^2 for a dataset {(x_j, y_j) for j in 1..=n_samples}.

The algorithm is only implemented for univariate regression. This means that b and y are scalars and W is just one column.

Examples

Here’s an example on how to train a linear regression model on the diabetes dataset

use linfa::traits::{Fit, Predict};
use linfa_linear::LinearRegression;
use linfa::prelude::SingleTargetRegression;

let dataset = linfa_datasets::diabetes();
let model = LinearRegression::default().fit(&dataset).unwrap();
let pred = model.predict(&dataset);
let r2 = pred.r2(&dataset).unwrap();
println!("r2 from prediction: {}", r2);

Implementations

Source

impl LinearRegression

Configure and fit a linear regression model

pub fn new() -> LinearRegression

Create a default linear regression model. By default, an intercept will be fitted.

pub fn with_intercept(self, intercept: bool) -> Self

Configure the linear regression model to fit an intercept.